@@ -28,7 +28,7 @@ mort.B2007 <-
              
     mort.B <- (1/(1 + exp(-logit)))
 
-    mort <- ifelse(mort.B  >= runif(length(tr$data[["ustandID"]]), 0,1), TRUE, FALSE )
+    mort <- ifelse(mort.B  >= runif(length(tr$data[["plot.id"]]), 0,1), TRUE, FALSE )
     
     return(mort)
 }
